# pyright: reportUnusedImport=false
import struct
from typing import Optional, Self, Sequence
from .. import abcs
from ..core import Request, serialize_bytes_to
_bytes = bytes | bytearray | memoryview
def get_payment_form(*, invoice: abcs.InputInvoice, theme_params: Optional[abcs.DataJson]) -> Request[abcs.payments.PaymentForm]:
    _buffer = bytearray(b'\xbb\x8d\x147')
    flags = (0 if theme_params is None else 1)
    _buffer += struct.pack('<I', flags)
    invoice._write_boxed_to(_buffer)
    if theme_params is not None:
      theme_params._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_payment_receipt(*, peer: abcs.InputPeer, msg_id: int) -> Request[abcs.payments.PaymentReceipt]:
    _buffer = bytearray(b'\xcc\xd1x$')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', msg_id)
    return Request(b'' + _buffer)
def validate_requested_info(*, save: bool, invoice: abcs.InputInvoice, info: abcs.PaymentRequestedInfo) -> Request[abcs.payments.ValidatedRequestedInfo]:
    _buffer = bytearray(b'+\xf1\xc8\xb6')
    flags = (1 if save else 0)
    _buffer += struct.pack('<I', flags)
    invoice._write_boxed_to(_buffer)
    info._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_payment_form(*, form_id: int, invoice: abcs.InputInvoice, requested_info_id: Optional[str], shipping_option_id: Optional[str], credentials: abcs.InputPaymentCredentials, tip_amount: Optional[int]) -> Request[abcs.payments.PaymentResult]:
    _buffer = bytearray(b'/R\x03-')
    flags = (0 if requested_info_id is None else 1) | (0 if shipping_option_id is None else 2) | (0 if tip_amount is None else 4)
    _buffer += struct.pack('<Iq', flags, form_id)
    invoice._write_boxed_to(_buffer)
    if requested_info_id is not None:
      serialize_bytes_to(_buffer, requested_info_id.encode('utf-8'))
    if shipping_option_id is not None:
      serialize_bytes_to(_buffer, shipping_option_id.encode('utf-8'))
    credentials._write_boxed_to(_buffer)
    if tip_amount is not None:
      _buffer += struct.pack(f'<q', tip_amount)
    return Request(b'' + _buffer)
def get_saved_info() -> Request[abcs.payments.SavedInfo]:
    _buffer = bytearray(b'K\x82}"')
    return Request(b'' + _buffer)
def clear_saved_info(*, credentials: bool, info: bool) -> Request[bool]:
    _buffer = bytearray(b'\xc1p=\xd8')
    flags = (1 if credentials else 0) | (2 if info else 0)
    _buffer += struct.pack('<I', flags)
    return Request(b'' + _buffer)
def get_bank_card_data(*, number: str) -> Request[abcs.payments.BankCardData]:
    _buffer = bytearray(b'y\xd7y.')
    serialize_bytes_to(_buffer, number.encode('utf-8'))
    return Request(b'' + _buffer)
def export_invoice(*, invoice_media: abcs.InputMedia) -> Request[abcs.payments.ExportedInvoice]:
    _buffer = bytearray(b'e\xb0\x91\x0f')
    invoice_media._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def assign_app_store_transaction(*, receipt: _bytes, purpose: abcs.InputStorePaymentPurpose) -> Request[abcs.Updates]:
    _buffer = bytearray(b'}t\xed\x80')
    serialize_bytes_to(_buffer, receipt)
    purpose._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def assign_play_market_transaction(*, receipt: abcs.DataJson, purpose: abcs.InputStorePaymentPurpose) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xd3P\xfd\xdf')
    receipt._write_boxed_to(_buffer)
    purpose._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def can_purchase_premium(*, purpose: abcs.InputStorePaymentPurpose) -> Request[bool]:
    _buffer = bytearray(b'\xb6\x9e\xc1\x9f')
    purpose._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
